@@ -3,6 +3,7 @@ import ckan.plugins.toolkit as tk
 
 import ckanext.comments.logic.action as action
 import ckanext.comments.logic.auth as auth
+import ckanext.comments.logic.validators as validators
 import ckanext.comments.helpers as helpers
 
 
@@ -11,6 +12,7 @@ class CommentsPlugin(plugins.SingletonPlugin):
     plugins.implements(plugins.IAuthFunctions)
     plugins.implements(plugins.IActions)
     plugins.implements(plugins.ITemplateHelpers)
+    plugins.implements(plugins.IValidators)
 
     # IConfigurer
 
@@ -33,3 +35,8 @@ class CommentsPlugin(plugins.SingletonPlugin):
 
     def get_helpers(self):
         return helpers.get_helpers()
+
+    # IValidators
+
+    def get_validators(self):
+        return validators.get_validators()
